DMIEntity mixin

Mixin applications

Properties

adx double?
ADX
getter/setter pair
adxr double?
ADXR (若不需要可去掉)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mdi double?
-DI
getter/setter pair
pdi double?
+DI
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited