PivotEntity mixin

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
pivot double?
getter/setter pair
pivotR1 double?
getter/setter pair
pivotR2 double?
getter/setter pair
pivotR3 double?
getter/setter pair
pivotS1 double?
getter/setter pair
pivotS2 double?
getter/setter pair
pivotS3 double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited