KChartWidget class

Inheritance

Constructors

KChartWidget(List<KLineEntity>? datas, ChartStyle chartStyle, ChartColors chartColors, {required bool isTrendLine, MainState mainState = MainState.MA, bool isShowMainState = true, List<SecondaryState> secondaryStates = const [SecondaryState.MACD], dynamic onSecondaryTap(int)?, bool volHidden = false, bool isLine = false, bool isTapShowInfoDialog = false, bool hideGrid = false, @Deprecated('Use `translations` instead.') bool isChinese = false, bool showNowPrice = true, bool showInfoDialog = true, bool materialInfoDialog = true, Map<String, ChartTranslations> translations = kChartTranslations, List<String> timeFormat = TimeFormat.YEAR_MONTH_DAY, dynamic onLoadMore(bool)?, int fixedLength = 2, List<int> maDayList = const [5, 10, 20], int flingTime = 600, double flingRatio = 0.5, Curve flingCurve = Curves.decelerate, dynamic isOnDrag(bool)?, VerticalTextAlignment verticalTextAlignment = VerticalTextAlignment.left, double? mainHeight, double? secondaryHeight, void onGoingUp(double probability)?, void onGoingDown(double probability)?, void onMainGoingUp(double probability)?, void onMainGoingDown(double probability)?, void onUpProbs(UpProbReport report)?, List<TradeMark> tradeMarks = const [], bool showTradeMarks = true})

Properties

chartColors ChartColors
final
chartStyle ChartStyle
final
datas List<KLineEntity>?
final
fixedLength int
final
flingCurve Curve
final
flingRatio double
final
flingTime int
final
hashCode int
The hash code for this object.
no setterinherited
hideGrid bool
final
isChinese bool
final
isLine bool
final
isOnDrag → dynamic Function(bool)?
final
isShowMainState bool
final
isTapShowInfoDialog bool
final
isTrendLine bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maDayList List<int>
final
mainHeight double?
final
mainState MainState
final
materialInfoDialog bool
final
onGoingDown → void Function(double probability)?
final
onGoingUp → void Function(double probability)?
final
onLoadMore → dynamic Function(bool)?
final
onMainGoingDown → void Function(double probability)?
final
onMainGoingUp → void Function(double probability)?
final
onSecondaryTap → dynamic Function(int)?
final
onUpProbs → void Function(UpProbReport report)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryHeight double?
final
secondaryStates List<SecondaryState>
final
showInfoDialog bool
final
showNowPrice bool
final
showTradeMarks bool
final
timeFormat List<String>
final
tradeMarks List<TradeMark>
final
translations Map<String, ChartTranslations>
final
verticalTextAlignment VerticalTextAlignment
final
volHidden bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _KChartWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited