SecondaryState enum
- Inheritance
- Available extensions
Values
- MACD → const SecondaryState
- KDJ → const SecondaryState
- RSI → const SecondaryState
- WR → const SecondaryState
- CCI → const SecondaryState
- DMI → const SecondaryState
- TRIX → const SecondaryState
- PPO → const SecondaryState
- TSI → const SecondaryState
- ICHIMOKU → const SecondaryState
- SAR → const SecondaryState
- AROON → const SecondaryState
- VORTEX → const SecondaryState
- ATR → const SecondaryState
- HV → const SecondaryState
- VWAP → const SecondaryState
- OBV → const SecondaryState
- ADL → const SecondaryState
- VIX → const SecondaryState
- ADX → const SecondaryState
- STDDEV → const SecondaryState
- STOCHASTIC → const SecondaryState
- WPR → const SecondaryState
- DEMARKER → const SecondaryState
- MOMENTUM → const SecondaryState
- MFI → const SecondaryState
- ENVELOPES → const SecondaryState
- VOLATILITY → const SecondaryState
- CMF → const SecondaryState
- CHAIKIN_OSC → const SecondaryState
- KLINGER → const SecondaryState
- VPT → const SecondaryState
- FORCE → const SecondaryState
- ROC → const SecondaryState
- ULTIMATE → const SecondaryState
- CONNORS_RSI → const SecondaryState
- STOCH_RSI → const SecondaryState
- RVI → const SecondaryState
- DPO → const SecondaryState
- KAMA → const SecondaryState
- HMA → const SecondaryState
- KELTNER → const SecondaryState
- DONCHIAN → const SecondaryState
- BOLL_BANDWIDTH → const SecondaryState
- CHAIKIN_VOLATILITY → const SecondaryState
- HV_PERCENTILE → const SecondaryState
- ATR_PERCENTILE → const SecondaryState
- ELDER_RAY → const SecondaryState
- ICHIMOKU_SPAN → const SecondaryState
- PIVOT → const SecondaryState
- GANN_FAN → const SecondaryState
- SUPER_TREND → const SecondaryState
- STC → const SecondaryState
- QQE → const SecondaryState
- WAVE_TREND → const SecondaryState
- CMO → const SecondaryState
- EOM → const SecondaryState
- PVI_NVI → const SecondaryState
- NONE → const SecondaryState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
Available on SecondaryState, provided by the SecondaryStateJson extension
将枚举值转换为 JSON(String)表示 -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecondaryState> - A constant List of the values in this enum, in order of their declaration.