MaCrossSignalProvider class
MA 金叉(短 MA 从下向上穿过中 MA);死叉反之
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isBuy(
List< KLineEntity> allData, int index) → bool -
override
-
isSell(
List< KLineEntity> allData, int index) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upProb(
List< KLineEntity> all, int i) → double? -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited