MainSignalProvider class abstract

Implementers

Constructors

MainSignalProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isBuy(List<KLineEntity> allData, int index) bool
isSell(List<KLineEntity> allData, int index) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upProb(List<KLineEntity> allData, int index) double?

Operators

operator ==(Object other) bool
The equality operator.
inherited