SecondarySignalProvider class abstract

统一接口

Implementers

Constructors

SecondarySignalProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isBuy(List<KLineEntity> all, int i) bool
isSell(List<KLineEntity> all, int i) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upProb(List<KLineEntity> all, int i) double
返回 0,1 的上涨概率

Operators

operator ==(Object other) bool
The equality operator.
inherited