TrendLineState class

Constructors

TrendLineState()

Properties

contentTop double?
getter/setter pair
currentX double
no setter
hashCode int
The hash code for this object.
no setterinherited
hasMetrics bool
no setter
maxValue double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double?
getter/setter pair
selectedX double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
setSelectedX(double x) → void
toString() String
A string representation of this object.
inherited
updateMetrics({required double maxValue, required double scale, required double contentTop}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited