TradeMark class
Constructors
Properties
- action → TradeAction
-
行为:入场/止盈/止损/时间止损等
final
- color → Color?
-
可选:颜色(不传用默认)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
对应K线索引(你的回测里:先用time映射到index)
final
- label → String?
-
可选:文字标签(例如“TP1 0.3”)
final
- price → double
-
发生价格(绘制Y坐标)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → TradeSide
-
做多/做空(当前只做多也可以都传TradeSide.long)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited