UpProbReport class
Constructors
-
UpProbReport({required int index, int? time, double? mainUp, required Map<
SecondaryState, double?> secondaryUps}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- mainUp → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secondaryUps
→ Map<
SecondaryState, double?> -
final
- time → int?
-
final
Methods
-
almostEquals(
UpProbReport other, {double eps = 1e-3}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited